@@ -37,10 +37,31 @@
 	#define strdup _strdup
 #endif
 
+#if defined (WIN32_DLL)
+static int winsock_refcount = 0;
+#endif
 
 irc_session_t * irc_create_session (irc_callbacks_t	* callbacks)
 {
-	irc_session_t * session = malloc (sizeof(irc_session_t));
+    irc_session_t * session;
+    
+#if defined (WIN32_DLL)
+    // From MSDN: The WSAStartup function typically leads to protocol-specific helper 
+    // DLLs being loaded. As a result, the WSAStartup function should not be called 
+    // from the DllMain function in a application DLL. This can potentially cause deadlocks.
+    if ( winsock_refcount == 0 )
+    {
+        WORD wVersionRequested = MAKEWORD (1, 1);
+        WSADATA wsaData;
+
+        if ( WSAStartup (wVersionRequested, &wsaData) != 0 )
+            return 0;
+        
+        winsock_refcount++;
+    }
+#endif
+    
+	session = malloc (sizeof(irc_session_t));
 
 	if ( !session )
 		return 0;
@@ -117,7 +138,14 @@ void irc_destroy_session (irc_session_t * session)
 	while ( session->dcc_sessions )
 		libirc_remove_dcc_session (session, session->dcc_sessions, 0);
 
+	libirc_mutex_destroy (&session->mutex_dcc);
+
 	free (session);
+    
+#if defined (WIN32_DLL)
+    if ( --winsock_refcount == 0 )
+        WSACleanup();
+#endif
 }
 
 
@@ -800,9 +828,12 @@ int irc_process_select_descriptors (irc_session_t * session, fd_set *in_set, fd_
 	libirc_dcc_process_descriptors (session, in_set, out_set);
 
 	// Handle "connection succeed" / "connection failed"
-	if ( session->state == LIBIRC_STATE_CONNECTING 
-	&& FD_ISSET (session->sock, out_set) )
+	if ( session->state == LIBIRC_STATE_CONNECTING )
 	{
+        // If the socket is not connected yet, wait longer - it is not an error
+        if ( !FD_ISSET (session->sock, out_set) )
+            return 0;
+        
 		// Now we have to determine whether the socket is connected 
 		// or the connect is failed
 		struct sockaddr_storage saddr, laddr;
