@@ -82,6 +82,9 @@ static int libirc_findcrorlf (char * buf, int length)
 
 static void libirc_event_ctcp_internal (irc_session_t * session, const char * event, const char * origin, const char ** params, unsigned int count)
 {
+	(void)event;
+	(void)count;
+
 	if ( origin )
 	{
 		char nickbuf[128], textbuf[256];
@@ -91,10 +94,16 @@ static void libirc_event_ctcp_internal (irc_session_t * session, const char * ev
 			irc_cmd_ctcp_reply (session, nickbuf, params[0]);
 		else if ( !strcmp (params[0], "VERSION") )
 		{
-			unsigned int high, low;
-			irc_get_version (&high, &low);
+			if ( !session->ctcp_version )
+			{
+				unsigned int high, low;
+				irc_get_version (&high, &low);
+
+				snprintf (textbuf, sizeof (textbuf), "VERSION libircclient by Georgy Yunaev ver.%d.%d", high, low);
+			}
+			else
+				snprintf (textbuf, sizeof (textbuf), "VERSION %s", session->ctcp_version);
 
-			sprintf (textbuf, "VERSION libirc by Georgy Yunaev ver.%d.%d", high, low);
 			irc_cmd_ctcp_reply (session, nickbuf, textbuf);
 		}
 		else if ( !strcmp (params[0], "FINGER") )
